<?php

declare(strict_types=1);

namespace Drupal\cortex_organisation\Form;

use CommerceGuys\Addressing\AddressFormat\AddressField;
use CommerceGuys\Addressing\AddressFormat\FieldOverride;
use Drupal\Core\Form\FormStateInterface;
use Drupal\cortex_general_settings\Form\CortexGeneralSettingsPluginForm;

/**
 * Provides a Cortex organisation form.
 */
class OrganisationForm extends CortexGeneralSettingsPluginForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'cortex_organisation_organisation';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $settings = $form_state->getBuildInfo()['args'][0];

    $form['address'] = [
      '#type' => 'address',
      '#title' => $this->t('Address'),
      '#default_value' => $settings['address'] ?? '',
      '#field_overrides' => [
        AddressField::GIVEN_NAME => FieldOverride::HIDDEN,
        AddressField::FAMILY_NAME => FieldOverride::HIDDEN,
      ],
      '#available_countries' => ['BE', 'NL', 'LU', 'FR', 'DE'],
    ];

    $form['phone'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Phone'),
      '#default_value' => $settings['phone'] ?? '',
    ];
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#default_value' => $settings['email'] ?? '',
    ];
    $form['website'] = [
      '#type' => 'url',
      '#title' => $this->t('Website'),
      '#default_value' => $settings['website'] ?? '',
    ];

    return $form;
  }

}
